package a01;

import java.io.*;

public class Horner {

static int maxPossibleExponent = 100;
static int [] coeffs = new int [maxPossibleExponent+1];
static int maxExp = 0;  // probably will be bigger

static boolean isNum(char c) { return (('0' <=c) && (c <= '9')); } //Character.isDigit(c); :-)

static void readPolynomial(String polyString) {
  char [] poly = new char[polyString.length()+1];   // polynomial with removed spaces
  int polyLen = 0;
  for(int i = 0; i < polyString.length(); i++)
    if (polyString.charAt(i) != ' ')
      poly[polyLen++] = polyString.charAt(i);       // remove the spaces
  poly[polyLen] = '#';                              // some sentinel is helpful

  int absCoeff;            // always nonnegative value of the current term coefficient
  int exp;                 // exponent
  int sign;                // only +1 or -1
  int i = 5;               // index to the poly array, 5 .. skip the "p(x)=" prefix
  while(i < polyLen) {            // read the terms, each in a single loop
    sign = (poly[i] == '-') ? -1 : +1;             // set the sign
    if ((poly[i] == '-') || (poly[i] == '+')) i++; // skip the sign if it exists
    absCoeff = isNum(poly[i]) ? 0 : 1;             // default coeff
    while (isNum(poly[i]))                         // update the coeff if it exists
      absCoeff = (int)(poly[i++]-48) + 10*absCoeff;
    if (poly[i] == '*')  i++;                      // skip the asterisk if it exists
    if (poly[i] != 'x') exp = 0;                   // only zero exponent possible
    else {                                         // 'x' has nonzero exponent
      exp = (poly[++i] == '^') ? 0 : 1;            // default exponent value
      if ( poly[i] == '^')                         // the exponent is explicitly there
        while (isNum(poly[++i]))                   // update the exponent
          exp = (int)(poly[i]-48) + 10*exp;
    }
    coeffs[exp] += sign*absCoeff;                  // register the coefficient
    if (exp > maxExp)                              // update the polynomial degree
      maxExp = exp;
  }
}

static String listPolyStdForm() {
  String p = (coeffs[maxExp] == 0) ? "0" : "";  // check zero polynomial
  for(int exp = maxExp; exp >=0; exp--)        // print one term
    if (coeffs[exp] != 0) {                    // print only terms with nonzero coeffs
      if (exp < maxExp)                        // sign of the general term
        p += (coeffs[exp] < 0) ? " - " : " + ";
      else if (coeffs[exp] < 0)                // sign of the maxExp term
        p += "-";
      if (exp > 0) {                           // non-constant term
        if (Math.abs(coeffs[exp]) != 1)        // 1's are not displayed in the term
          p += String.valueOf(Math.abs(coeffs[exp])) + "*";
        p += "x";
        if (exp > 1)                           // exponent value
          p += "^" +  String.valueOf(exp);
       }
       else                                    // exp == 0, just abs val of the coeff
          p += String.valueOf(Math.abs(coeffs[exp]));
    }
  return p;
}

static String toSignString(int n){  // missing in java std library...
    return  ((n >= 0) ? "+" : "") + Integer.toString(n);
}

static String listHornerRecur(int exp) {
  if (exp == maxExp)
    return Integer.toString(coeffs[exp]);
  if (exp == maxExp-1)
    return Integer.toString(coeffs[exp]) + toSignString(coeffs[exp+1]) +"*x";
  return Integer.toString(coeffs[exp]) + "+("+listHornerRecur(exp+1) +")*x";
}

static int polyValue(int x) { // a la Horner
  int val = coeffs[maxExp];
  for (int exp = maxExp-1; exp >= 0; exp--)
    val = coeffs[exp] + val*x;
  return val;
}

public static void main(String[] args) throws IOException {
  BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
  readPolynomial(br.readLine());
  System.out.printf("%s\n", "p(x) = " + listPolyStdForm());
  System.out.printf("%s\n", "p(x) = " + listHornerRecur(0));
  int valueOfX;
  do {
     valueOfX = Integer.valueOf(br.readLine().trim());
     System.out.printf("p(%d) = %d\n", valueOfX, polyValue(valueOfX));
  } while (valueOfX != 0);
 }

// for those who dislike the recursive solution:
static String listHornerLoop() {
  if (maxExp == 0) return String.valueOf(coeffs[0]);
  String h = "";
  for (int exp = 0; exp < maxExp-1; exp++)
    h += String.valueOf(coeffs[exp]) + "+(";
  h += String.valueOf(coeffs[maxExp-1]) + toSignString(coeffs[maxExp]) + "*x";
  for (int exp = maxExp-2; exp >= 0; exp--)
    h += ")*x";
  return h;
}

}